@@ -1,4 +1,4 @@
 `segmented.default` <-
-function(obj, seg.Z, psi, control=seg.control(), model.frame=TRUE, ...){
+function(obj, seg.Z, psi, control=seg.control(), model=TRUE, ...){
             stop("No default method for segmented")
             }
